Resource operations
===================

grafanarmadillo.find
--------------------

.. automodule:: grafanarmadillo.find
    :members:

grafanarmadillo.dashboarder
---------------------------

.. automodule:: grafanarmadillo.dashboarder
    :members:

grafanarmadillo.alerter
-----------------------

.. automodule:: grafanarmadillo.alerter
    :members:


grafanarmadillo.templator
-------------------------

.. automodule:: grafanarmadillo.templator
    :members:
